@@ -201,7 +201,7 @@ class WithTargets(BaseCommand):
             self.targets = args
         else:
             if self.targets_required:
-                raise UVCError("You must list at least one file to remove.")
+                raise UVCError("You must list at least one file.")
             else:
                 self.targets = None
             
@@ -241,7 +241,39 @@ class status(WithTargets):
     
     reads_remote = False
     writes_remote = False
-    
+
+class log(WithTargets):
+    """Retrieve the log of changes to a file/project."""
+
+    reads_remote = False
+    writes_remote = False
+
+class cat(BaseCommand):
+    """Retrieve a specific revision of a file."""
+    reads_remote = False
+    writes_remote = False
+
+    parser = OptionParser()
+    parser.add_option('-r', "--revision", dest="revision", help="revision identifier")
+
+    def __init__(self, context, args):
+        super(cat, self).__init__(context, args)
+        options, args = self.parser.parse_args(args)
+        self.revision = options.revision
+        for target in args:
+            context.validate_exists(target)
+        self.targets = args
+
+    def command_parts(self):
+        parts = [ "cat" ]
+        revision = self.revision
+        if revision is not None:
+            parts.extend([ "-r", revision ])
+        targets = self.targets
+        if targets:
+            parts.extend(targets)
+        return parts
+
 class revert(WithTargets):
     """Revert a set of files"""
     
@@ -315,4 +347,4 @@ def get_command(context, args):
     """Retrieve a command object based on the command line given"""
     command_class = get_command_class(context, args)
     return command_class(context, args)
-    
\ No newline at end of file
+    
