@@ -5,6 +5,7 @@ import os
 import subprocess
 import tempfile
 import logging
+from cStringIO import StringIO
 
 from uvc import commands, hg, svn
 from uvc.util import run_in_directory
@@ -212,7 +213,7 @@ def run_command(command, context):
         
     log.debug("Running: %s", (command_line,))
     log.debug("Working dir: %s", context.working_dir)
-    
+
     run_in_directory(context.working_dir, command_line, 
         timeout=context.timeout, 
         output=context.output)
@@ -270,4 +271,30 @@ def run(args=None):
     
     command = _get_command_with_blanks_filled_in(context, args, dialect)
     run_command(command, context)
-    
\ No newline at end of file
+
+def call_uvc(directory, sub_command, params):
+    """ Utility to call UVC from a given directory. This roughly the same as:
+    $ cd $directory
+    $ uvc $sub_command $params | $return
+    'params' should be an array of params to pass into the sub_command.
+    Returns an IOWrapper containing a StringIO with the output or containing the
+    object passed in on the output_file parameter """
+    output_file = StringIO()
+    output = IOWrapper(output_file)
+    context = SecureContext(directory, output=output)
+    dialect = infer_dialect(directory);
+    command_class = get_command_class(context, [ sub_command ], dialect)
+    command = command_class.from_args(context, params)
+    run_command(command, context)
+    # TODO: This is a bit of a hack to allow call_uvc_data to get at the command
+    output.command = command
+    return output
+
+def call_uvc_data(directory, sub_command, params):
+    """ Utility to call UVC from a given directory. This roughly the same as:
+    $ cd $directory
+    $ uvc $sub_command $params | get_structured_data($return)
+    'params' should be an array of params to pass into the sub_command.
+    Returns output from command.get_structured_data rather than a string. """
+    output = call_uvc(directory, sub_command, params)
+    return output.command.get_structured_data(output.file.getvalue())
