@@ -51,9 +51,9 @@ class SVNCommand(DialectCommand):
     dialect_name = "svn"
 
 def _add_auth_info(auth, parts):
+    parts.insert(0, "--non-interactive")
     if auth:
         if auth['type'] == "ssh":
-            parts.insert(0, "--non-interactive")
             parts.insert(1, "--trust-server-cert")
             parts.insert(2, "")
             parts.insert(3, "")
@@ -62,7 +62,6 @@ def _add_auth_info(auth, parts):
             # setting StrictHostKeyChecking to no is less than ideal...
             #parts.insert(2, "ssh -i %s -o StrictHostKeyChecking=no" % (auth['key']))
         elif auth['type'] == "password":
-            parts.insert(0, "--non-interactive")
             parts.insert(1, "--username")
             parts.insert(2, auth['username'])
             parts.insert(3, "--password")
@@ -214,6 +213,14 @@ class status(SVNCommand):
     reads_remote = False
     writes_remote = False
 
+class log(SVNCommand):
+    reads_remote = False
+    writes_remote = False
+
+class cat(SVNCommand):
+    reads_remote = False
+    writes_remote = False
+
 class revert(SVNCommand):
     reads_remote = False
     writes_remote = False
