@@ -36,14 +36,14 @@ def test_clone_command_conversion():
                                     "paver"])
     svn_clone = svn.clone(generic_clone)
     svn_clone_command = " ".join(svn_clone.get_command_line())
-    assert svn_clone_command == "svn checkout http://paver.googlecode.com/svn/trunk/ paver"
+    assert svn_clone_command == "svn --non-interactive checkout http://paver.googlecode.com/svn/trunk/ paver"
     
 def test_convert_function():
     generic_clone = commands.clone(context, ["http://paver.googlecode.com/svn/trunk/", 
                                     "paver"])
     svn_clone = dialect.convert(generic_clone)
     svn_clone_command = " ".join(svn_clone.get_command_line())
-    assert svn_clone_command == "svn checkout http://paver.googlecode.com/svn/trunk/ paver"
+    assert svn_clone_command == "svn --non-interactive checkout http://paver.googlecode.com/svn/trunk/ paver"
     
 def test_convert_unknown_command():
     class Foo(object):
@@ -103,7 +103,8 @@ def test_push_after_commit():
     
     generic_push = commands.push(test_context, [])
     result = dialect.convert(generic_push)
-    assert result.get_command_line() == ["svn", "commit", "-m", 
+    assert result.get_command_line() == ["svn", 
+        "--non-interactive", "commit", "-m", 
         "test message1\n\ntest message2\n\n"]
     
 def test_diff_command():
@@ -237,8 +238,10 @@ def test_svn_native_commands():
         command_line = command.get_command_line()
         if command_line is None:
             return
-        args = t.args
-        assert command_line == args
+        
+        final_args = t.args
+        final_args.insert(1, "--non-interactive")
+        assert command_line == final_args
     
     for t in tests:
         yield test_one, t
